==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_administrator.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_administrator.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("ADMSLAN_0", "New user/admin entry created for");
define("ADMSLAN_1", "now has admin status.");
define("ADMSLAN_2", "updated in database.");
define("ADMSLAN_3", "is the main site administrator and cannot be edited.");
define("ADMSLAN_4", "Continue");
define("ADMSLAN_5", "Error!");
define("ADMSLAN_6", "is the main site administrator and cannot be deleted.");

define("ADMSLAN_13", "Existing Administrators");


define("ADMSLAN_16", "Admin Name");
define("ADMSLAN_17", "Admin Password");
define("ADMSLAN_18", "Permissions");
define("ADMSLAN_19", "Alter site preferences");
define("ADMSLAN_20", "Alter Menus");
define("ADMSLAN_21", "Modify administrator permissions");
define("ADMSLAN_22", "Moderate users/bans etc");
define("ADMSLAN_23", "Create/edit custom pages/menus");
define("ADMSLAN_24", "Manage download categories");
define("ADMSLAN_25", "Upload /manage files");
define("ADMSLAN_26", "Oversee news categories");
define("ADMSLAN_27", "Oversee link categories");
define("ADMSLAN_28", "Take site down for maintenance");
define("ADMSLAN_29", "Manage banners");
define("ADMSLAN_30", "Configure news feed headlines");
define("ADMSLAN_31", "Configure emoticons");
define("ADMSLAN_32", "Configure front page content");
define("ADMSLAN_33", "Configure log/stats");
define("ADMSLAN_34", "Configure meta tags");
define("ADMSLAN_35", "Configure public file uploads");
define("ADMSLAN_36", "Configure Image Settings");
define("ADMSLAN_37", "Moderate comments");
// define("ADMSLAN_38", "Moderate/configure chatbox");
define("ADMSLAN_39", "Post news");
define("ADMSLAN_40", "Post links");
//obsolete 	define("ADMSLAN_41", "Post articles");
//obsolete 	define("ADMSLAN_42", "Post reviews");
//obsolete - use in v0.8: Configure URLs	 define("ADMSLAN_43", "Post content pages");
define("ADMSLAN_44", "Post downloads");
define("ADMSLAN_45", "Post polls");
define("ADMSLAN_46", "Welcome message");
define("ADMSLAN_47", "Moderate submitted news");

define("ADMSLAN_49", "Check All");
define("ADMSLAN_51", "Uncheck All");
define("ADMSLAN_52", "Update administrator");
define("ADMSLAN_53", "Add administrator");
define("ADMSLAN_54", "Site Administrators");

define("ADMSLAN_55", "Field(s) left blank");

define("ADMSLAN_56", "Site Administrator");

define("ADMSLAN_58", "Main Site Administrator");
define("ADMSLAN_59", "Remove Admin Status");
define("ADMSLAN_60", "Are you sure you want to remove admin status from");
define("ADMSLAN_61", "Administrator deleted");

define("ADMSLAN_62", "Plugin Manager");

define("ADMSLAN_64", "Clear the system cache");
define("ADMSLAN_65", "Configure mail settings and mailout");
define("ADMSLAN_66", "Configure Search");
define("ADMSLAN_67", "Scan with file inspector");
define("ADMSLAN_68", "Configure email notification");
define("ADMSLAN_69", "is already an administrator and must be edited.");

define("ADMSLAN_70", "Return to Administrator Listing");
define("ADMSLAN_71", "Click here to display privileges");  

?>

==> e107-1.0.0.tbz: www/e107/e107_languages/English/admin/lan_administrator.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_administrator.php $
|     $Revision: 11678 $
|     $Id: lan_administrator.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("ADMSLAN_0", "New user/admin entry created for");
define("ADMSLAN_1", "now has admin status.");
define("ADMSLAN_2", "updated in database.");
define("ADMSLAN_3", "is the main site administrator and cannot be edited.");
define("ADMSLAN_4", "Continue");
define("ADMSLAN_5", "Error!");
define("ADMSLAN_6", "is the main site administrator and cannot be deleted.");

define("ADMSLAN_13", "Existing Administrators");


define("ADMSLAN_16", "Admin Name");
define("ADMSLAN_17", "Admin Password");
define("ADMSLAN_18", "Permissions");
define("ADMSLAN_19", "Alter site preferences");
define("ADMSLAN_20", "Alter Menus");
define("ADMSLAN_21", "Modify administrator permissions");
define("ADMSLAN_22", "Moderate users/bans etc");
define("ADMSLAN_23", "Create/edit custom pages/menus");
define("ADMSLAN_24", "Manage download categories");
define("ADMSLAN_25", "Upload /manage files");
define("ADMSLAN_26", "Oversee news categories");
define("ADMSLAN_27", "Oversee link categories");
define("ADMSLAN_28", "Take site down for maintenance");
define("ADMSLAN_29", "Manage banners");
define("ADMSLAN_30", "Configure news feed headlines");
define("ADMSLAN_31", "Configure emoticons");
define("ADMSLAN_32", "Configure front page content");
define("ADMSLAN_33", "Configure log/stats");
define("ADMSLAN_34", "Configure meta tags");
define("ADMSLAN_35", "Configure public file uploads");
define("ADMSLAN_36", "Configure Image Settings");
define("ADMSLAN_37", "Moderate comments");
// define("ADMSLAN_38", "Moderate/configure chatbox");
define("ADMSLAN_39", "Post news");
define("ADMSLAN_40", "Post links");
//obsolete 	define("ADMSLAN_41", "Post articles");
//obsolete 	define("ADMSLAN_42", "Post reviews");
//obsolete - use in v0.8: Configure URLs	 define("ADMSLAN_43", "Post content pages");
define("ADMSLAN_44", "Post downloads");
define("ADMSLAN_45", "Post polls");
define("ADMSLAN_46", "Welcome message");
define("ADMSLAN_47", "Moderate submitted news");

define("ADMSLAN_49", "Check All");
define("ADMSLAN_51", "Uncheck All");
define("ADMSLAN_52", "Update administrator");
define("ADMSLAN_53", "Add administrator");
define("ADMSLAN_54", "Site Administrators");

define("ADMSLAN_55", "Field(s) left blank");

define("ADMSLAN_56", "Site Administrator");

define("ADMSLAN_58", "Main Site Administrator");
define("ADMSLAN_59", "Remove Admin Status");
define("ADMSLAN_60", "Are you sure you want to remove admin status from");
define("ADMSLAN_61", "Administrator deleted");

define("ADMSLAN_62", "Plugin Manager");

define("ADMSLAN_64", "Clear the system cache");
define("ADMSLAN_65", "Configure mail settings and mailout");
define("ADMSLAN_66", "Configure Search");
define("ADMSLAN_67", "Scan with file inspector");
define("ADMSLAN_68", "Configure email notification");
define("ADMSLAN_69", "is already an administrator and must be edited.");

define("ADMSLAN_70", "Return to Administrator Listing");
define("ADMSLAN_71", "Click here to display privileges");  

?>
